@@ -5,9 +5,10 @@ use warnings;
 
 use Pod::Manual;
 
-my $manual = Pod::Manual->new( title => 'Catalyst' );
+my $manual = Pod::Manual->new({ title => 'Catalyst' });
 
-$manual->add_chapters( qw/  Catalyst::Manual::About 
+$manual->add_chapter( $_ ) for qw/  
+                            Catalyst::Manual::About 
                             Catalyst::Manual::Actions
                             Catalyst::Manual::Cookbook
                             Catalyst::Manual::DevelopmentProcess
@@ -24,10 +25,8 @@ $manual->add_chapters( qw/  Catalyst::Manual::About
                             Catalyst::Manual::Tutorial::Testing
                             Catalyst::Manual::Tutorial::AdvancedCRUD
                             Catalyst::Manual::Tutorial::Appendices
-                            Catalyst::Manual::WritingPlugins / );
+                            Catalyst::Manual::WritingPlugins /;
 
-my $pdf_file = 'catalyst_manual.pdf';
-$manual->save_as_pdf( $pdf_file );
-
-print "pdf document '$pdf_file' created\n";
+#print $manual->as_docbook; exit;
+$manual->save_as_pdf( 'catalyst_manual.pdf' );
 
